summaryrefslogtreecommitdiffstats
path: root/larn
diff options
context:
space:
mode:
authormrg <mrg@NetBSD.org>2006-05-11 10:23:24 +0000
committermrg <mrg@NetBSD.org>2006-05-11 10:23:24 +0000
commitfd7d7ad818aabc89daff7701812f9ce68c076b9e (patch)
treea6cfdb9386083e1297bd6aa79d0a44af95f01817 /larn
parent24a934cdee9f410c2b1106f81040c195558ced7c (diff)
downloadbsdgames-darwin-fd7d7ad818aabc89daff7701812f9ce68c076b9e.tar.gz
bsdgames-darwin-fd7d7ad818aabc89daff7701812f9ce68c076b9e.tar.zst
bsdgames-darwin-fd7d7ad818aabc89daff7701812f9ce68c076b9e.zip
lrint() -> larn_lrint().
Diffstat (limited to 'larn')
-rw-r--r--larn/diag.c10
-rw-r--r--larn/extern.h4
-rw-r--r--larn/io.c8
3 files changed, 11 insertions, 11 deletions
diff --git a/larn/diag.c b/larn/diag.c
index 7982e23b..486b2ee3 100644
--- a/larn/diag.c
+++ b/larn/diag.c
@@ -1,9 +1,9 @@
-/* $NetBSD: diag.c,v 1.9 2000/07/03 03:57:42 matt Exp $ */
+/* $NetBSD: diag.c,v 1.10 2006/05/11 10:23:24 mrg Exp $ */
/* diag.c Larn is copyrighted 1986 by Noah Morgan. */
#include <sys/cdefs.h>
#ifndef lint
-__RCSID("$NetBSD: diag.c,v 1.9 2000/07/03 03:57:42 matt Exp $");
+__RCSID("$NetBSD: diag.c,v 1.10 2006/05/11 10:23:24 mrg Exp $");
#endif /* not lint */
#include <sys/types.h>
@@ -259,7 +259,7 @@ restoregame(fname)
lrfill((char *) &cell[k * MAXX * MAXY], sizeof(struct cel) * MAXY * MAXX);
lrfill((char *) &c[0], 100 * sizeof(long));
- gltime = lrint();
+ gltime = larn_lrint();
level = c[CAVELEVEL] = lgetc();
playerx = lgetc();
playery = lgetc();
@@ -304,7 +304,7 @@ restoregame(fname)
}
time(&zzz);
- initialtime = zzz - lrint();
+ initialtime = zzz - larn_lrint();
fstat(fd, &filetimes); /* get the creation and modification time of
* file */
lrfill((char *) &zzz, sizeof(long));
@@ -318,7 +318,7 @@ restoregame(fname)
return;
} /* died a post mortem death */
oldx = oldy = 0;
- i = lrint(); /* inode # */
+ i = larn_lrint(); /* inode # */
if (i && (filetimes.st_ino != i))
fsorry();
lrclose();
diff --git a/larn/extern.h b/larn/extern.h
index 2e119ba6..fe3af458 100644
--- a/larn/extern.h
+++ b/larn/extern.h
@@ -1,4 +1,4 @@
-/* $NetBSD: extern.h,v 1.4 2004/01/27 20:30:30 jsm Exp $ */
+/* $NetBSD: extern.h,v 1.5 2006/05/11 10:23:24 mrg Exp $ */
/*
* Copyright (c) 1997 Christos Zoulas. All rights reserved.
@@ -135,7 +135,7 @@ void lprintf(const char *, ...);
void lprint(long);
void lwrite(char *, int);
long lgetc(void);
-long lrint(void);
+long larn_lrint(void);
void lrfill(char *, int);
char *lgetw(void);
char *lgetl(void);
diff --git a/larn/io.c b/larn/io.c
index 3f2d34b4..e7446e67 100644
--- a/larn/io.c
+++ b/larn/io.c
@@ -1,4 +1,4 @@
-/* $NetBSD: io.c,v 1.15 2005/02/03 02:23:02 perry Exp $ */
+/* $NetBSD: io.c,v 1.16 2006/05/11 10:23:24 mrg Exp $ */
/*
* io.c Larn is copyrighted 1986 by Noah Morgan.
@@ -27,7 +27,7 @@
* FILE INPUT ROUTINES
*
* long lgetc() read one character from input buffer
* long lrint() read one integer from input buffer
* lrfill(address,number) put input bytes into a buffer char
* *lgetw() get a whitespace ended word from
* input char *lgetl() get a \n or EOF ended line
@@ -62,7 +62,7 @@
*/
#include <sys/cdefs.h>
#ifndef lint
-__RCSID("$NetBSD: io.c,v 1.15 2005/02/03 02:23:02 perry Exp $");
+__RCSID("$NetBSD: io.c,v 1.16 2006/05/11 10:23:24 mrg Exp $");
#endif /* not lint */
#include "header.h"
@@ -462,7 +462,7 @@ lgetc()
* Returns the int read
*/
long
-lrint()
+larn_lrint()
{
unsigned long i;
i = 255 & lgetc();
@@ -27,7 +27,7 @@
*
* long lgetc() read one character from input buffer
- * long lrint() read one integer from input buffer
+ * long larn_lrint() read one integer from input buffer
* lrfill(address,number) put input bytes into a buffer char
* *lgetw() get a whitespace ended word from